From: Nishanth Aravamudan <nacc@us.ibm.com>
To: gregkh@us.ibm.com, marcel@holtmann.org, maxk@qualcomm.com,
jt@hpl.hp.com, perex@suse.cz, linux-dvb-maintainer@linuxtv.org,
johnpol@2ka.mipt.ru
Cc: linux-usb-devel@lists.sourceforge.net,
bluez-devel@lists.sourceforge.net,
irda-users@lists.sourceforge.net, alsa-devel@alsa-project.org,
linux-dvb@linuxtv.org, sensors@stimpy.netroedge.com
Subject: [PATCH 1/63] usb/message: make usb_{control,bulk}_msg() use msecs
Date: Tue, 8 Feb 2005 16:12:32 -0800 [thread overview]
Message-ID: <20050209001232.GC5661@us.ibm.com> (raw)
Hi,
Sent to everyone so that build and compile tests will be possible. Only Greg
should need to pull this into a tree, though, to send upstream.
Thanks,
Nish
Description: Change the units of the timeout parameter in both usb_control_msg()
and usb_bulk_msg() from jiffies to milliseconds. This is the core patch upon
which the remaining ones will be built. Patch is compile-tested.
Signed-off-by: Nishanth Aravamudan <nacc@us.ibm.com>
--- 2.6.11-rc3-kj-v/drivers/usb/core/message.c 2005-02-03 16:57:40.000000000 -0800
+++ 2.6.11-rc3-kj/drivers/usb/core/message.c 2005-02-08 16:07:32.000000000 -0800
@@ -98,7 +98,7 @@ int usb_internal_control_msg(struct usb_
usb_fill_control_urb(urb, usb_dev, pipe, (unsigned char *)cmd, data,
len, usb_api_blocking_completion, NULL);
- retv = usb_start_wait_urb(urb, timeout, &length);
+ retv = usb_start_wait_urb(urb, msecs_to_jiffies(timeout), &length);
if (retv < 0)
return retv;
else
@@ -115,7 +115,7 @@ int usb_internal_control_msg(struct usb_
* @index: USB message index value
* @data: pointer to the data to send
* @size: length in bytes of the data to send
* @timeout: time in jiffies to wait for the message to complete before
* timing out (if 0 the wait is forever)
* Context: !in_interrupt ()
*
@@ -163,7 +163,7 @@ int usb_control_msg(struct usb_device *d
* @data: pointer to the data to send
* @len: length in bytes of the data to send
* @actual_length: pointer to a location to put the actual length transferred in bytes
* @timeout: time in jiffies to wait for the message to complete before
* timing out (if 0 the wait is forever)
* Context: !in_interrupt ()
*
@@ -196,7 +196,7 @@ int usb_bulk_msg(struct usb_device *usb_
usb_fill_bulk_urb(urb, usb_dev, pipe, data, len,
usb_api_blocking_completion, NULL);
- return usb_start_wait_urb(urb,timeout,actual_length);
+ return usb_start_wait_urb(urb,msecs_to_jiffies(timeout),actual_length);
}
/*-------------------------------------------------------------------*/
next reply other threads:[~2005-02-09 0:12 UTC|newest]
Thread overview: 3+ messages / expand[flat|nested] mbox.gz Atom feed top
2005-02-09 0:12 Nishanth Aravamudan [this message]
2005-02-15 22:29 ` [linux-usb-devel] [PATCH 1/63] usb/message: make usb_{control,bulk}_msg() use msecs Greg KH
2005-02-15 23:10 ` Nishanth Aravamudan
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20050209001232.GC5661@us.ibm.com \
--to=nacc@us.ibm.com \
--cc=alsa-devel@alsa-project.org \
--cc=bluez-devel@lists.sourceforge.net \
--cc=gregkh@us.ibm.com \
--cc=irda-users@lists.sourceforge.net \
--cc=johnpol@2ka.mipt.ru \
--cc=jt@hpl.hp.com \
--cc=linux-dvb-maintainer@linuxtv.org \
--cc=linux-dvb@linuxtv.org \
--cc=linux-usb-devel@lists.sourceforge.net \
--cc=marcel@holtmann.org \
--cc=maxk@qualcomm.com \
--cc=perex@suse.cz \
--cc=sensors@stimpy.netroedge.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -115,7 +115,7 @@ int usb_internal_control_msg(struct usb_
* @data: pointer to the data to send
* @size: length in bytes of the data to send
- * @timeout: time in jiffies to wait for the message to complete before
+ * @timeout: time in msecs to wait for the message to complete before
* timing out (if 0 the wait is forever)
* Context: !in_interrupt ()
@@ -163,7 +163,7 @@ int usb_control_msg(struct usb_device *d
* @len: length in bytes of the data to send
* @actual_length: pointer to a location to put the actual length transferred in bytes
- * @timeout: time in jiffies to wait for the message to complete before
+ * @timeout: time in msecs to wait for the message to complete before
* timing out (if 0 the wait is forever)
* Context: !in_interrupt ()
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox